@@ -82,7 +82,7 @@ class SyncariRestClient:
         except Exception as e:
             err = Response()
             err.status_code = 400
-            err.reason = err_msg
+            err.reason = str(e)
             err.raw = str(e)
             err.url = url
             raise SyncariException(error_response=ErrorResponse(message=err_msg, response=err))
