@@ -38,7 +38,7 @@ class SimpleRestSynapse(Synapse):
     def read(self):
         return super().read()
 
-    def get(self):
+    def get_by_id(self):
         return self.__crud(CrudOperation.GET)
 
     def create(self):
