@@ -40,8 +40,8 @@ class MockSynapse(Synapse):
         eds.append(Record.parse_obj({'name':'MockRecord','values':{'key':'val'}}))
         return ReadResponse(watermark=watermark,data=eds)
 
-    def get(self):
-        self.__print(self.get.__name__, self.request)
+    def get_by_id(self):
+        self.__print(self.get_by_id.__name__, self.request)
         eds = []
         eds.append(Record.parse_obj({'name':'MockRecord','values':{'key':'val'}}))
         return eds
@@ -112,7 +112,7 @@ def test_read_synapse_request():
     assert resp is not None
 
 def test_get_synapse_request():
-    synapse_request = Request(type=RequestType.GET,
+    synapse_request = Request(type=RequestType.GET_BY_ID,
         connection=get_connection(),
         body=SyncRequest(
             entity=Schema(apiName='test',displayName='Test',attributes=[]), 
